@@ -1,6 +1,8 @@
 package Bundle::WWW::Search;
 
-$VERSION = '1.01';
+$VERSION = '1.03';
+
+1;
 
 __END__
 
@@ -14,6 +16,8 @@ C<perl -MCPAN -e 'install Bundle::WWW::Search'>
 
 =head1 CONTENTS
 
+File::Spec		- prerequisite
+
 Bundle::LWP		- prerequisite
 
 URI::Escape             - prerequisite
